# Generated by Django 6.0.1 on 2026-01-28 09:08

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("sandwitches", "0015_order_completed_alter_order_status_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="user",
            name="theme",
            field=models.CharField(
                choices=[("light", "Light"), ("dark", "Dark")],
                default="light",
                max_length=10,
            ),
        ),
    ]
