# Generated by Django 6.0.3 on 2026-03-18 12:51

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("sandwitches", "0023_historicalrecipe_instagram_likes_count_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="historicalrecipe",
            name="calories",
            field=models.PositiveIntegerField(
                blank=True, null=True, verbose_name="Calories (kcal)"
            ),
        ),
        migrations.AddField(
            model_name="historicalrecipe",
            name="cook_time",
            field=models.PositiveIntegerField(
                blank=True, null=True, verbose_name="Cook Time (mins)"
            ),
        ),
        migrations.AddField(
            model_name="historicalrecipe",
            name="prep_time",
            field=models.PositiveIntegerField(
                blank=True, null=True, verbose_name="Prep Time (mins)"
            ),
        ),
        migrations.AddField(
            model_name="recipe",
            name="calories",
            field=models.PositiveIntegerField(
                blank=True, null=True, verbose_name="Calories (kcal)"
            ),
        ),
        migrations.AddField(
            model_name="recipe",
            name="cook_time",
            field=models.PositiveIntegerField(
                blank=True, null=True, verbose_name="Cook Time (mins)"
            ),
        ),
        migrations.AddField(
            model_name="recipe",
            name="prep_time",
            field=models.PositiveIntegerField(
                blank=True, null=True, verbose_name="Prep Time (mins)"
            ),
        ),
    ]
