# Generated by Django 6.0.3 on 2026-03-18 17:10

import django.core.validators
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        (
            "sandwitches",
            "0024_historicalrecipe_calories_historicalrecipe_cook_time_and_more",
        ),
    ]

    operations = [
        migrations.AlterField(
            model_name="historicalrecipe",
            name="servings",
            field=models.IntegerField(
                blank=True,
                default=1,
                validators=[django.core.validators.MinValueValidator(1)],
            ),
        ),
        migrations.AlterField(
            model_name="recipe",
            name="servings",
            field=models.IntegerField(
                blank=True,
                default=1,
                validators=[django.core.validators.MinValueValidator(1)],
            ),
        ),
    ]
