# Generated by Django 6.0.3 on 2026-03-11 13:34

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("sandwitches", "0021_alter_order_tracking_token"),
    ]

    operations = [
        migrations.AddField(
            model_name="historicalrecipe",
            name="instagram_uploaded",
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name="recipe",
            name="instagram_uploaded",
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name="setting",
            name="instagram_enabled",
            field=models.BooleanField(
                default=False, help_text="Enable uploading new recipes to Instagram"
            ),
        ),
        migrations.AddField(
            model_name="setting",
            name="instagram_initial_uploaded",
            field=models.BooleanField(
                default=False,
                help_text="Whether the initial recipe has been uploaded to Instagram",
            ),
        ),
        migrations.AddField(
            model_name="setting",
            name="instagram_password",
            field=models.CharField(
                blank=True,
                help_text="The password of your Instagram account",
                max_length=255,
                null=True,
            ),
        ),
        migrations.AddField(
            model_name="setting",
            name="instagram_username",
            field=models.CharField(
                blank=True,
                help_text="The username of your Instagram account",
                max_length=255,
                null=True,
            ),
        ),
    ]
